Crate agave_io_uring

Crate agave_io_uring 

Structs

Completion
Context object passed to RingOp::complete.
FixedSlab
Ring
An io_uring instance.

Traits

RingAccess
Trait for accessing the context and pushing operations to the Ring.
RingOp
Trait for operations that can be submitted to a Ring.

Functions

io_uring_supported