pub struct Completion<'a, T, E: RingOp<T>> { /* private fields */ }This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Context object passed to RingOp::complete.
Implementations
Sourceimpl<T, E: RingOp<T>> Completion<'_, T, E>
impl<T, E: RingOp<T>> Completion<'_, T, E>
Sourcepub fn context(&self) -> &T
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn context(&self) -> &T
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Returns a reference to the context value stored in a Ring.
Sourcepub fn context_mut(&mut self) -> &mut T
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn context_mut(&mut self) -> &mut T
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Returns a mutable reference to the context value stored in a Ring.
Sourcepub fn push(&mut self, op: E)
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn push(&mut self, op: E)
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Pushes an operation to the submission queue.
This can be used to push new operations from within RingOp::complete.
See also Ring::push.